Extension

Struct Extension 

pub struct Extension { /* private fields */ }
An Extension associates a file extension (e.g. .py) to a set of shared libraries.

This details how a Zenoh-Flow runtime should load nodes that have the url of their implementation with this extension.

Zenoh-Flow only supports node implementation in the form of shared libraries. To support additional implementation — for instance Python scripts — a Zenoh-Flow runtime needs to be informed on (i) which shared libraries it should load and (ii) how it should make these shared libraries “load” the node implementation.

To support an extension on a Zenoh-Flow runtime, one can either detail them in the configuration file of the runtime or through the dedicated method.

Example configuration

(Yaml)

file_extension: py
libraries:
  source: /home/zenoh-flow/libpy_source.so
  operator: /home/zenoh-flow/libpy_operator.so
  sink: /home/zenoh-flow/libpy_sink.so

Implementations

Source

impl Extension

pub fn file_extension(&self) -> &str

Returns the file extension associated with this extension.

Example
assert_eq!(extension.file_extension(), "py");
pub fn source(&self) -> &PathBuf

Returns the path of the shared library responsible for loading Source nodes for this file extension.

Example
assert_eq!(extension.source().to_str(), Some("/home/zenoh-flow/libpy_source.so"));
pub fn operator(&self) -> &PathBuf

Returns the path of the shared library responsible for loading Operator nodes for this file extension.

Example
assert_eq!(extension.operator().to_str(), Some("/home/zenoh-flow/libpy_operator.so"));
pub fn sink(&self) -> &PathBuf

Returns the path of the shared library responsible for loading Sink nodes for this file extension.

Example
assert_eq!(extension.sink().to_str(), Some("/home/zenoh-flow/libpy_sink.so"));